spoon.routing.NetMessage

Package spoon :: Package routing :: Class NetMessage |
[show private | hide private]
[frames | no frames]

## Type NetMessage

    object --+
             |
            NetMessage

NetMessage is the protocol unit for the networking component of spoon. It contains a src (source node id), dest (destination node id), message type and an object attachment. The object attachment can of course be anything at all that's serializable. The message type indicates what subsystem the message should be handled by. Currently only messaging is implemented, but in the future, who knows.

To Do: At some point in the future I'd like to add an HMAC here, but I have to sort out how keys and such are shared at a protocol level here.

Method Summary
| `__init__(self, src, dst, mtype, attach)`
Inherited from object
| ``__delattr__`(...)` x.__delattr__('name') <==> del x.name
| ``__getattribute__`(...)` x.__getattribute__('name') <==> x.name
| ``__hash__`(x)` x.__hash__() <==> hash(x)
| ``__new__`(T, S, ...)` T.__new__(S, ...) -> a new object with type S, a subtype of T
| ``__reduce__`(...)` helper for pickle
| ``__reduce_ex__`(...)` helper for pickle
| ``__repr__`(x)` x.__repr__() <==> repr(x)
| ``__setattr__`(...)` x.__setattr__('name', value) <==> x.name = value
| ``__str__`(x)` x.__str__() <==> str(x)

Generated by Epydoc 2.1 on Sun Nov 26 15:27:51 2006 | http://epydoc.sf.net